@@ -22,7 +22,11 @@ class HedgeOrchestrator(PipeOrchestrator):
                 row[f"hedge_dominant"] =res_df.iloc[res_df["size"].argmax()]["label"]
                 out_arr.append(row)
         out_df: pd.DataFrame = pd.DataFrame(out_arr)
-        out_df.fillna(0, inplace=True)
+
+        str_cols = [x for x in out_df.columns.tolist() if x.endswith("_words")]
+        num_cols = [x for x in out_df.columns.tolist() if( x.endswith("_count") or x.endswith("_ratio") )]
+        out_df[[str_cols]] = out_df[[str_cols]].fillna("")
+        out_df[[num_cols]] = out_df[[num_cols]].fillna(0)
         return out_df
 
 
